diff win64-msvc/include/pa_win_wdmks.h @ 145:13a516fa8999

Update PortAudio build for Win64
author Chris Cannam <cannam@all-day-breakfast.com>
date Tue, 10 Jan 2017 11:28:20 +0000
parents 1c067f014d80
children
line wrap: on
line diff
--- a/win64-msvc/include/pa_win_wdmks.h	Mon Jan 09 13:57:37 2017 +0000
+++ b/win64-msvc/include/pa_win_wdmks.h	Tue Jan 10 11:28:20 2017 +0000
@@ -1,7 +1,7 @@
 #ifndef PA_WIN_WDMKS_H
 #define PA_WIN_WDMKS_H
 /*
- * $Id: pa_win_wdmks.h 1812 2012-02-14 09:32:57Z robiwan $
+ * $Id$
  * PortAudio Portable Real-Time Audio Library
  * WDM/KS specific extensions
  *
@@ -52,13 +52,44 @@
 extern "C"
 {
 #endif /* __cplusplus */
+
+    /** Flags to indicate valid fields in PaWinWDMKSInfo.
+     @see PaWinWDMKSInfo
+     @version Available as of 19.5.0.
+    */
+    typedef enum PaWinWDMKSFlags
+    {
+        /** Makes WDMKS use the supplied latency figures instead of relying on the frame size reported
+         by the WaveCyclic device. Use at own risk!
+        */
+        paWinWDMKSOverrideFramesize   = (1 << 0),
+
+        /** Makes WDMKS (output stream) use the given channelMask instead of the default.
+          @version Available as of 19.5.0.
+        */
+        paWinWDMKSUseGivenChannelMask = (1 << 1),
+
+    } PaWinWDMKSFlags;
+
     typedef struct PaWinWDMKSInfo{
         unsigned long size;             /**< sizeof(PaWinWDMKSInfo) */
         PaHostApiTypeId hostApiType;    /**< paWDMKS */
         unsigned long version;          /**< 1 */
 
-        /* The number of packets to use for WaveCyclic devices, range is [2, 8]. Set to zero for default value of 2. */
+        /** Flags indicate which fields are valid.
+         @see PaWinWDMKSFlags
+         @version Available as of 19.5.0.
+        */
+        unsigned long flags;
+
+        /** The number of packets to use for WaveCyclic devices, range is [2, 8]. Set to zero for default value of 2. */
         unsigned noOfPackets;
+
+        /** If paWinWDMKSUseGivenChannelMask bit is set in flags, use this as channelMask instead of default.
+         @see PaWinWDMKSFlags
+         @version Available as of 19.5.0.
+        */
+        unsigned channelMask;
     } PaWinWDMKSInfo;
 
     typedef enum PaWDMKSType